Stan Math Library: stan/math/prim/scal/meta/likely.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Macros
likely.hpp File Reference

Go to the source code of this file.

## Macros
#define | likely(x) (x)
#define | unlikely(x) (x)

## Macro Definition Documentation

#define likely | ( |  | x | ) | (x)

Definition at line 8 of file likely.hpp.

#define unlikely | ( |  | x | ) | (x)

Definition at line 9 of file likely.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.